==> jc-1.4.0.tar.gz: polyglot/ext/param/types/Subst__5fc__24TypeXform.h <==
// public class polyglot.ext.param.types.Subst_c$TypeXform

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3223e1399cafed59 polyglot_ext_param_types_Subst__5fc__24TypeXform

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_param_types_Subst__5fc__24TypeXform_H_
#define _JC_polyglot_ext_param_types_Subst__5fc__24TypeXform_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_polyglot_ext_param_types_Subst__5fc$object;

// Typedefs
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$sub_refs	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$sub_refs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$sub_nonrefs	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$sub_nonrefs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$refs	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$refs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$nonrefs	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$nonrefs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$object	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$object;

typedef const struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vmethods	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vmethods;
typedef const struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vtable	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vtable;
typedef const struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vtype	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vtype;

// Constructors
extern void _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$method$_init$6b84d2d2ede79d86(_jc_env *, struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$object *, struct _jc_polyglot_ext_param_types_Subst__5fc$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$method$transform$ebefcdad8030daa7(_jc_env *, struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$method_info$transform$ebefcdad8030daa7;

// Virtual methods structure
struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vmethods {
	struct _jc_java_lang_Object$object	*(*transform$ebefcdad8030daa7)(_jc_env *, struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vmethods	polyglot_ext_param_types_Subst__5fc__24TypeXform;
};

// Vtype
struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vtype {
	_jc_type			type;
	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$sub_refs {
	struct _jc_polyglot_ext_param_types_Subst__5fc$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$refs {
    _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$sub_refs	polyglot_ext_param_types_Subst__5fc__24TypeXform;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$sub_nonrefs	polyglot_ext_param_types_Subst__5fc__24TypeXform;
};

// Object instance structure
struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$object {
	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vtype	*vtype;
	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vtype _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_param_types_Subst__5fc__24TypeXform, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$class_object;

#endif	/* _JC_polyglot_ext_param_types_Subst__5fc__24TypeXform_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/param/types/Subst__5fc__24TypeXform.h <==
// public class polyglot.ext.param.types.Subst_c$TypeXform

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3223e1399cafed59 polyglot_ext_param_types_Subst__5fc__24TypeXform

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_param_types_Subst__5fc__24TypeXform_H_
#define _JC_polyglot_ext_param_types_Subst__5fc__24TypeXform_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_polyglot_ext_param_types_Subst__5fc$object;

// Typedefs
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$sub_refs	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$sub_refs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$sub_nonrefs	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$sub_nonrefs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$refs	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$refs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$nonrefs	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$nonrefs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$object	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$object;

typedef const struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vmethods	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vmethods;
typedef const struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vtable	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vtable;
typedef const struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vtype	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vtype;

// Constructors
extern void _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$method$_init$6b84d2d2ede79d86(_jc_env *, struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$object *, struct _jc_polyglot_ext_param_types_Subst__5fc$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$method$transform$ebefcdad8030daa7(_jc_env *, struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$method_info$transform$ebefcdad8030daa7;

// Virtual methods structure
struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vmethods {
	struct _jc_java_lang_Object$object	*(*transform$ebefcdad8030daa7)(_jc_env *, struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vmethods	polyglot_ext_param_types_Subst__5fc__24TypeXform;
};

// Vtype
struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vtype {
	_jc_type			type;
	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$sub_refs {
	struct _jc_polyglot_ext_param_types_Subst__5fc$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$refs {
    _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$sub_refs	polyglot_ext_param_types_Subst__5fc__24TypeXform;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$sub_nonrefs	polyglot_ext_param_types_Subst__5fc__24TypeXform;
};

// Object instance structure
struct _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$object {
	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vtype	*vtype;
	_jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$vtype _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_param_types_Subst__5fc__24TypeXform, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_param_types_Subst__5fc__24TypeXform$class_object;

#endif	/* _JC_polyglot_ext_param_types_Subst__5fc__24TypeXform_H_ */
